@@ -307,7 +307,7 @@ def stock_xgsglb_em(symbol: str = "全部股票") -> pd.DataFrame:
                 "SECURITY_NAME": "股票简称",
                 "TRADE_MARKET_CODE": "-",
                 "APPLY_CODE": "申购代码",
-                "TRADE_MARKET": "-",
+                "TRADE_MARKET": "交易所",
                 "MARKET_TYPE": "-",
                 "ORG_TYPE": "-",
                 "ISSUE_NUM": "发行总数",
@@ -359,6 +359,7 @@ def stock_xgsglb_em(symbol: str = "全部股票") -> pd.DataFrame:
                 "股票代码",
                 "股票简称",
                 "申购代码",
+                "交易所",
                 "发行总数",
                 "网上发行",
                 "顶格申购需配市值",
